/**
 * 小程序端  孵化器入口  企业相关路由
 */

import * as asyncHandler from 'express-async-handler';
import * as enterpriseBiz from '../../biz/enterprise/enterprise';
import { checkFuHuaQiToken } from '../../middleware/user';
import { eccReqMustHaveParam } from '../../util/verificationParam';

export function setRouter(httpServer) {
    httpServer.post('/fuhuaqi/enterprise/register', checkFuHuaQiToken, asyncHandler(registerEnterprise));
    httpServer.post('/fuhuaqi/enterprise/updateregister', checkFuHuaQiToken, asyncHandler(updateRegisterEnterprise));
    httpServer.post('/fuhuaqi/enterprise/move', checkFuHuaQiToken, asyncHandler(moveInEnterprise));
    httpServer.post('/fuhuaqi/enterprise/updatemove', checkFuHuaQiToken, asyncHandler(updateMoveInEnterprise));
    httpServer.post('/fuhuaqi/enterprise/select', checkFuHuaQiToken, asyncHandler(selectEnterpriseInfo));
    httpServer.post('/fuhuaqi/enterprise/delete', checkFuHuaQiToken, asyncHandler(delEnterpriseInfo));
}


/**
 * 添加新注册的企业信息
 * @param req 
 * @param res 
 */
async function registerEnterprise(req, res) {
    let reqConf = {form: 'Object' };
    let { form } = eccReqMustHaveParam(reqConf, req.body);
    const Uscc = req.headers.uscc;

    let result = await enterpriseBiz.registerEnterprise(Uscc, form);
    res.success(result);
}


/**
 * 修改新注册的企业信息
 * @param req 
 * @param res 
 */
async function updateRegisterEnterprise(req, res) {
    let reqConf = {form: 'Object' };
    let { form } = eccReqMustHaveParam(reqConf, req.body);
    const Uscc = req.headers.uscc;

    let result = await enterpriseBiz.updateRegisterEnterprise(Uscc, form);
    res.success(result);
}


/**
 * 添加迁入的企业信息 
 * @param req 
 * @param res 
 */
 async function moveInEnterprise(req, res) {
    let reqConf = {form: 'Object' };
    let { form } = eccReqMustHaveParam(reqConf, req.body);
    const Uscc = req.headers.uscc;

    let result = await enterpriseBiz.moveInEnterprise(Uscc, form);
    res.success(result);
}


/**
 * 修改迁入企业登记信息 
 * @param req 
 * @param res 
 */
async function updateMoveInEnterprise(req, res) {
    let reqConf = {form: 'Object' };
    let { form } = eccReqMustHaveParam(reqConf, req.body);
    const Uscc = req.headers.uscc;

    let result = await enterpriseBiz.updateMoveInEnterprise(Uscc, form);
    res.success(result);
}


/**
 * 查询迁入企业登记信息或新建企业登录信息 
 * 回显
 * @param req 
 * @param res 
 */
 async function selectEnterpriseInfo(req, res) {
    /*这里改成了用DraftId,为了不改前端 依然使用uscc这个参数名称*/
    let reqConf = {uscc: 'String' };
    let { uscc } = eccReqMustHaveParam(reqConf, req.body); 

    let result = await enterpriseBiz.getEnterpriseByDraftId(uscc);
    res.success(result);
}


/**
 * 删除迁入企业登记信息或新建企业登录信息 
 * @param req 
 * @param res 
 */
async function delEnterpriseInfo(req, res) {
     /*这里改成了用DraftId,为了不改前端 依然使用uscc这个参数名称*/
    let reqConf = {uscc: 'String' };
    let { uscc } = eccReqMustHaveParam(reqConf, req.body);

    let result = await enterpriseBiz.deleteEnterpriseByDraftId(uscc);
    res.success(result);
}